@@ -65,6 +65,16 @@ class TextFormatter(BaseFormatter):
     def remove_invalid_chars(self, text):
         return re.sub(INVALID_CHARS.get(self.lang), "", text)
 
+    def is_valid_non_punc_char(self, c):
+        if c in string.punctuation:
+            return False
+
+        if self.lang == "en":
+            return ord(c) < 128
+
+        if self.lang == "de":
+            return ord(c) < 128 or c in "äöüÄÖÜß"
+
     def format_text(self, text):
         """
         a whitelisted fashion as opposed to tokenizing
@@ -117,7 +127,7 @@ class TextFormatter(BaseFormatter):
                 is_valid = True  # finance number, or time
             elif c in CURRENCY_WORD_MAPPING[self.lang]:
                 is_valid = True
-            elif c not in string.punctuation and ord(c) < 128:  # must be ascii
+            elif self.is_valid_non_punc_char(c):
                 is_valid = True
 
             if is_valid:
